==> ktp-text-ui_19.12.3.orig.tar.xz: ktp-text-ui-19.12.3/filters/urlexpansion/ktptextui_message_filter_urlexpansion.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Name=Short URLs
Name[ar]=وصلات مقصّرة
Name[bs]=Kratke URL adrese
Name[ca]=URL breus
Name[ca@valencia]=URL breus
Name[cs]=Krátké URL
Name[da]=Korte URL'er
Name[de]=Kurz-URLs
Name[el]=Συντομευμένα URL
Name[en_GB]=Short URLs
Name[es]=URL abreviadas
Name[et]=Lühi-URL-id
Name[eu]=URL laburrak
Name[fi]=Lyhyet verkko-osoitteet
Name[fr]=URL réduites
Name[gl]=Enderezos URL curtos
Name[hu]=Rövid URL-ek
Name[ia]=Monstra URLs
Name[it]=URL brevi
Name[kk]=Қысқа URL-дер
Name[ko]=단축 URL
Name[nb]=Korte URL-er
Name[nds]=Kort URLs
Name[nl]=Korte URL's
Name[nn]=Korte nettadresser
Name[pa]=ਛੋਟੇ URL
Name[pl]=Krótkie adresy URL
Name[pt]=URL's Curtos
Name[pt_BR]=URLs curtas
Name[ro]=URL-uri scurte
Name[ru]=Короткие адреса
Name[sk]=Krátke URL
Name[sl]=Kratki naslovi URL
Name[sr]=Скраћени УРЛ‑ови
Name[sr@ijekavian]=Скраћени УРЛ‑ови
Name[sr@ijekavianlatin]=Skraćeni URL‑ovi
Name[sr@latin]=Skraćeni URL‑ovi
Name[sv]=Korta webbadresser
Name[tr]=Kısa adresler
Name[uk]=Короткі адреси
Name[x-test]=xxShort URLsxx
Name[zh_CN]=短 URL
Name[zh_TW]=短網址
Comment=Shows the actual URL to which a shortened URL is redirecting to
Comment[ar]=يظهر العنوان الفعليّ الّذي يعيد العنوان المقصّر التّوجيه إليه
Comment[bs]=Prikazuje stvarni URL na koji je skraćeni preusmjeren
Comment[ca]=Mostra l'URL real al qual es redirigeix un URL breu
Comment[ca@valencia]=Mostra l'URL real al qual es redirigeix un URL breu
Comment[cs]=Zobrazí skutečné URL, na které je přesměrováno zkrácené URL
Comment[da]=Viser den faktiske URL som en afkortet URL videresender til
Comment[de]=Zeigt die tatsächliche Adresse (URL), auf die eine gekürzte URL umgeleitet wird
Comment[el]=Εμφανίζει το πραγματικό URL στο οποίο ανακατευθύνεται το συντομευμένο
Comment[en_GB]=Shows the actual URL to which a shortened URL is redirecting to
Comment[es]=Muestra la URL real a la que redirecciona una URL abreviada
Comment[et]=Tegeliku URL-i näitamine, millele lühendatud URL ümber suunab
Comment[eu]=Erakutsi URL laburtu batek izatez birbideratzen duen URLa
Comment[fi]=Näyttää, mihin osoitteeseen lyhennetty verkko-osoite ohjaa
Comment[fr]=Affiche l'URL courante vers laquelle pointe une URL réduite
Comment[gl]=Mostra o URL real ao que dirixe un URL acurtado.
Comment[hu]=Megjeleníti azt az aktuális URL-t, amelyre a rövidített URL átirányít
Comment[ia]=Il monstra le URL actual ubi on redirige un URL abbreviate
Comment[it]=Mostra l'URL vero a cui si viene rediretti da un URL abbreviato
Comment[kk]=Қысқа URL бағыттайтын шын URL-адресін көрсету
Comment[ko]=단축 URL이 가리키는 실제 URL 보이기
Comment[nb]=Vis den virkelige URL-en som en forkortet URL viser til
Comment[nds]=Wiest de redige URL, op de en afkört URL wiest
Comment[nl]=Toont de actuele URL waarnaar de korte URL verwijst
Comment[nn]=Vis den utvida nettadressa som forkorta adresser peikar til
Comment[pl]=Pokazuje rzeczywisty adres URL, na który wskazuje ten skrócony
Comment[pt]=Mostra o URL real para onde aponta um URL curto
Comment[pt_BR]=Mostra a URL real para onde direciona uma URL curta
Comment[ro]=Arată URL-ul real spre care redirecționează un URL scurtat
Comment[ru]=Показывать полные адреса URL, на которые перенаправляют сокращённые
Comment[sk]=Zobrazí aktuálne URL, na ktoré je presmerované skrátené URL
Comment[sl]=Prikaže dejanski URL na katerega kaže skrajšan URL
Comment[sr]=Приказује стварни УРЛ на који скраћени преусмерава
Comment[sr@ijekavian]=Приказује стварни УРЛ на који скраћени преусмерава
Comment[sr@ijekavianlatin]=Prikazuje stvarni URL na koji skraćeni preusmerava
Comment[sr@latin]=Prikazuje stvarni URL na koji skraćeni preusmerava
Comment[sv]=Visar den verkliga webbadressen som en avkortad webbadress leder till
Comment[tr]=Kısaltılmış URL'nin yönlendireceği asıl URL'yi gösterir
Comment[uk]=Показує справжню адресу, до якої переспрямовуватиме вас скорочена адреса
Comment[x-test]=xxShows the actual URL to which a shortened URL is redirecting toxx
Comment[zh_CN]=显示短 URL 的实际 URL
Comment[zh_TW]=顯示短網址將導向的實際網址
Type=Service
ServiceTypes=KTpTextUi/MessageFilter
X-KDE-Library=ktptextui_message_filter_urlexpansion
X-KDE-PluginInfo-Author=Anant Kamath
X-KDE-PluginInfo-Email=kamathanant@gmail.org
X-KDE-PluginInfo-Name=urlexpansion
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@

==> ktp-text-ui_21.12.3.orig.tar.xz: ktp-text-ui-21.12.3/filters/urlexpansion/ktptextui_message_filter_urlexpansion.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Name=Short URLs
Name[ar]=وصلات مقصّرة
Name[bs]=Kratke URL adrese
Name[ca]=URL breus
Name[ca@valencia]=URL breus
Name[cs]=Krátké URL
Name[da]=Korte URL'er
Name[de]=Kurz-URLs
Name[el]=Συντομευμένα URL
Name[en_GB]=Short URLs
Name[es]=URL abreviadas
Name[et]=Lühi-URL-id
Name[eu]=URL laburrak
Name[fi]=Lyhyet verkko-osoitteet
Name[fr]=URL réduites
Name[gl]=Enderezos URL curtos
Name[hu]=Rövid URL-ek
Name[ia]=Monstra URLs
Name[it]=URL brevi
Name[kk]=Қысқа URL-дер
Name[ko]=단축 URL
Name[nb]=Korte URL-er
Name[nds]=Kort URLs
Name[nl]=Korte URL's
Name[nn]=Korte nettadresser
Name[pa]=ਛੋਟੇ URL
Name[pl]=Krótkie adresy URL
Name[pt]=URL's Curtos
Name[pt_BR]=URLs curtas
Name[ro]=URL-uri scurte
Name[ru]=Короткие адреса
Name[sk]=Krátke URL
Name[sl]=Kratki naslovi URL
Name[sr]=Скраћени УРЛ‑ови
Name[sr@ijekavian]=Скраћени УРЛ‑ови
Name[sr@ijekavianlatin]=Skraćeni URL‑ovi
Name[sr@latin]=Skraćeni URL‑ovi
Name[sv]=Korta webbadresser
Name[tr]=Kısa adresler
Name[uk]=Короткі адреси
Name[x-test]=xxShort URLsxx
Name[zh_CN]=短 URL
Name[zh_TW]=短網址
Comment=Shows the actual URL to which a shortened URL is redirecting to
Comment[ar]=يظهر العنوان الفعليّ الّذي يعيد العنوان المقصّر التّوجيه إليه
Comment[bs]=Prikazuje stvarni URL na koji je skraćeni preusmjeren
Comment[ca]=Mostra l'URL real al qual es redirigeix un URL breu
Comment[ca@valencia]=Mostra l'URL real al qual es redirigeix un URL breu
Comment[cs]=Zobrazí skutečné URL, na které je přesměrováno zkrácené URL
Comment[da]=Viser den faktiske URL som en afkortet URL videresender til
Comment[de]=Zeigt die tatsächliche Adresse (URL), auf die eine gekürzte URL umgeleitet wird
Comment[el]=Εμφανίζει το πραγματικό URL στο οποίο ανακατευθύνεται το συντομευμένο
Comment[en_GB]=Shows the actual URL to which a shortened URL is redirecting to
Comment[es]=Muestra la URL real a la que redirecciona una URL abreviada
Comment[et]=Tegeliku URL-i näitamine, millele lühendatud URL ümber suunab
Comment[eu]=Erakutsi URL laburtu batek izatez birbideratzen duen URLa
Comment[fi]=Näyttää, mihin osoitteeseen lyhennetty verkko-osoite ohjaa
Comment[fr]=Affiche l'URL courante vers laquelle pointe une URL réduite
Comment[gl]=Mostra o URL real ao que dirixe un URL acurtado.
Comment[hu]=Megjeleníti azt az aktuális URL-t, amelyre a rövidített URL átirányít
Comment[ia]=Il monstra le URL actual ubi on redirige un URL abbreviate
Comment[it]=Mostra l'URL vero a cui si viene rediretti da un URL abbreviato
Comment[kk]=Қысқа URL бағыттайтын шын URL-адресін көрсету
Comment[ko]=단축 URL이 가리키는 실제 URL 표시
Comment[nb]=Vis den virkelige URL-en som en forkortet URL viser til
Comment[nds]=Wiest de redige URL, op de en afkört URL wiest
Comment[nl]=Toont de actuele URL waarnaar de korte URL verwijst
Comment[nn]=Vis den utvida nettadressa som forkorta adresser peikar til
Comment[pl]=Pokazuje rzeczywisty adres URL, na który wskazuje ten skrócony
Comment[pt]=Mostra o URL real para onde aponta um URL curto
Comment[pt_BR]=Mostra a URL real para onde direciona uma URL curta
Comment[ro]=Arată URL-ul real spre care redirecționează un URL scurtat
Comment[ru]=Показывать полные адреса URL, на которые перенаправляют сокращённые
Comment[sk]=Zobrazí aktuálne URL, na ktoré je presmerované skrátené URL
Comment[sl]=Prikaže dejanski URL na katerega kaže skrajšan URL
Comment[sr]=Приказује стварни УРЛ на који скраћени преусмерава
Comment[sr@ijekavian]=Приказује стварни УРЛ на који скраћени преусмерава
Comment[sr@ijekavianlatin]=Prikazuje stvarni URL na koji skraćeni preusmerava
Comment[sr@latin]=Prikazuje stvarni URL na koji skraćeni preusmerava
Comment[sv]=Visar den verkliga webbadressen som en avkortad webbadress leder till
Comment[tr]=Kısaltılmış URL'nin yönlendireceği asıl URL'yi gösterir
Comment[uk]=Показує справжню адресу, до якої переспрямовуватиме вас скорочена адреса
Comment[x-test]=xxShows the actual URL to which a shortened URL is redirecting toxx
Comment[zh_CN]=显示短 URL 的实际 URL
Comment[zh_TW]=顯示短網址將導向的實際網址
Type=Service
ServiceTypes=KTpTextUi/MessageFilter
X-KDE-Library=ktptextui_message_filter_urlexpansion
X-KDE-PluginInfo-Author=Anant Kamath
X-KDE-PluginInfo-Email=kamathanant@gmail.org
X-KDE-PluginInfo-Name=urlexpansion
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@
